# Weaviate-CLI (beta) <img alt='Weaviate logo' src='https://raw.githubusercontent.com/creativesoftwarefdn/weaviate/19de0956c69b66c5552447e84d016f4fe29d12c9/docs/assets/weaviate-logo.png' width='180' align='right' />

_CLI tool for for Weaviate_

## Installation

Install using: `pip install weaviate-cli`\
Run using: `weaviate --help`

## Build Status

| Badge   | Status        |
| -------- |:-------------:|
| Travis   | [![Build Status](https://api.travis-ci.org/semi-technologies/weaviate-cli.svg?branch=master)](https://travis-ci.org/creativesoftwarefdn/weaviate-cli/branches)
